==> colord-kde_0.5.0.orig.tar.xz: colord-kde-0.5.0/colord-kded/ProfilesWatcher.h <==
/***************************************************************************
 *   Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PROFILES_WATCHER_H
#define PROFILES_WATCHER_H

#include <KDirWatch>

#include <QThread>
#include <QVariantList>
#include <QFileInfo>

class Edid;
class ProfilesWatcher : public QThread
{
    Q_OBJECT
public:
    explicit ProfilesWatcher(QObject *parent = 0);

public slots:
    void scanHomeDirectory();
    void createIccProfile(bool isLaptop, const Edid &edid);

signals:
    void scanFinished();

private slots:
    void addProfile(const QString &fileInfo);
    void removeProfile(const QString &filename);

private:
    QString profilesPath() const;

    KDirWatch *m_dirWatch = nullptr;
};

#endif // PROFILES_WATCHER_H

==> colord-kde_25.04.0.orig.tar.xz: colord-kde-25.04.0/colord-kded/ProfilesWatcher.h <==
/***************************************************************************
 *   Copyright (C) 2012 by Daniel Nicoletti <dantti12@gmail.com>           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#pragma once

#include <KDirWatch>

#include <QThread>

class Edid;
class ProfilesWatcher : public QThread
{
    Q_OBJECT
public:
    explicit ProfilesWatcher(QObject *parent = nullptr);

public Q_SLOTS:
    void scanHomeDirectory();
    void createIccProfile(bool isLaptop, const Edid &edid);

Q_SIGNALS:
    void scanFinished();

private Q_SLOTS:
    void addProfile(const QString &fileInfo);
    void removeProfile(const QString &filename);

private:
    QString profilesPath() const;

    KDirWatch *m_dirWatch = nullptr;
};
